@@ -13,58 +13,45 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging
 import monascastatsd
 
+from monasca_common.kafka.consumer import KafkaConsumer
+from monasca_common.kafka.producer import KafkaProducer
 from processors.alarm_processor import AlarmProcessor
 from processors.base import BaseProcessor
-from processors.kafka_consumer import KafkaConsumer
-from processors.kafka_producer import KafkaProducer
 from processors.notification_processor import NotificationProcessor
 
+log = logging.getLogger(__name__)
+
 
 class NotificationEngine(object):
     def __init__(self, config):
         self._topics = {}
         self._topics['notification_topic'] = config['kafka']['notification_topic']
         self._topics['retry_topic'] = config['kafka']['notification_retry_topic']
-
         self._statsd = monascastatsd.Client(name='monasca',
                                             dimensions=BaseProcessor.dimensions)
-
         self._consumer = KafkaConsumer(config['kafka']['url'],
                                        config['zookeeper']['url'],
                                        config['zookeeper']['notification_path'],
                                        config['kafka']['group'],
                                        config['kafka']['alarm_topic'])
-
         self._producer = KafkaProducer(config['kafka']['url'])
-
-        if 'ssl' in config['mysql']:
-            ssl_config = config['mysql']['ssl']
-        else:
-            ssl_config = None
-
-        self._alarms = AlarmProcessor(config['processors']['alarm']['ttl'],
-                                      config['mysql']['host'],
-                                      config['mysql']['user'],
-                                      config['mysql']['passwd'],
-                                      config['mysql']['db'],
-                                      ssl_config)
-
+        self._alarm_ttl = config['processors']['alarm']['ttl']
+        self._alarms = AlarmProcessor(self._alarm_ttl, config)
         self._notifier = NotificationProcessor(config['notification_types'])
 
     def run(self):
         finished_count = self._statsd.get_counter(name='alarms_finished_count')
-
         for alarm in self._consumer:
-
+            log.debug('Received alarm >|%s|<', str(alarm))
             notifications, partition, offset = self._alarms.to_notification(alarm)
-
             if notifications:
                 sent, failed = self._notifier.send(notifications)
-                self._producer.publish(self._topics['notification_topic'], sent)
-                self._producer.publish(self._topics['retry_topic'], failed)
-
-            self._consumer.commit([partition])
-
+                self._producer.publish(self._topics['notification_topic'],
+                                       [i.to_json() for i in sent])
+                self._producer.publish(self._topics['retry_topic'],
+                                       [i.to_json() for i in failed])
+            self._consumer.commit()
             finished_count.increment()
